
# Slot: has device


connects an entity to one or more (medical) devices

URI: [biolink:has_device](https://w3id.org/biolink/vocab/has_device)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [Device](Device.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [Treatment](Treatment.md)
